@@ -32,7 +32,7 @@ if __name__ == '__main__':
     epoch = epoch_row["median"].item()
     epoch_low_err = epoch_row["lower_error"].item()
     epoch_up_err = epoch_row["upper_error"].item()
-    duration_row = fit_derived_results[fit_derived_results["#property"].str.contains("Total transit duration")]
+    duration_row = fit_derived_results[fit_derived_results["#property"].str.contains("Full-transit duration")]
     duration = duration_row["value"].item()
     duration_low_err = duration_row["lower_error"].item()
     duration_up_err = duration_row["upper_error"].item()
