@@ -3,9 +3,9 @@
 rm tests.log
 rm dist* -r
 set -e
-#tox -r > tests.log
-#tests_results=$(cat tests.log | grep "congratulations")
-#if ! [[ -z ${tests_results} ]]; then
+tox -r > tests.log
+tests_results=$(cat tests.log | grep "congratulations")
+if ! [[ -z ${tests_results} ]]; then
   git_tag=$1
   sed -i '6s/.*/version = "'${git_tag}'"/' setup.py
   git add setup.py
@@ -23,7 +23,7 @@ set -e
   echo "Push docker image with tag ${git_tag}"
   sudo docker push sherlockpipe/sherlockpipe:latest
   sudo docker push sherlockpipe/sherlockpipe:${git_tag}
-#else
-#  echo "TESTS FAILED. See tests.log"
-#fi
-#rm dist* -r
+else
+  echo "TESTS FAILED. See tests.log"
+fi
+rm dist* -r
