@@ -29,7 +29,7 @@ class QuorumSnrBorderCorrectedSignalSelector(BasicSignalSelector):
             while j < len(index_snr_period_t0_array):
                 compared_period = index_snr_period_t0_array[j][2]
                 compared_t0 = index_snr_period_t0_array[j][3]
-                if abs(period - compared_period) < 0.025 and abs(t0 - compared_t0) < 0.01:
+                if abs(period - compared_period) < 0.025 and abs(t0 - compared_t0) < 0.04:
                     votes[j] = i
                 j = j + 1
             i = i + 1
@@ -37,14 +37,21 @@ class QuorumSnrBorderCorrectedSignalSelector(BasicSignalSelector):
         corrected_snrs = [index_snr_period_t0_array[key][1] +
                           index_snr_period_t0_array[key][1] * (votes_count - 1) / number_of_voters * self.strength
                 for key, votes_count in enumerate(votes_counts)]
-        best_signal_snr = np.nanmax(corrected_snrs)
-        best_signal_snr_index = np.nanargmax(corrected_snrs)
-        best_signal = transit_results[best_signal_snr_index]
-        max_votes_rate = max(votes_counts) / len(votes)
-        if best_signal_snr > snr_min and max_votes_rate >= self.min_quorum:  # and SDE[a] > SDE_min and FAP[a] < FAP_max):
-            best_signal_score = 1
-        else:
+        number_corrected_snrs_length = len(np.where(~np.isnan(corrected_snrs)))
+        if number_corrected_snrs_length == 0:
             best_signal_score = 0
+            best_signal = 0
+            best_signal_snr_index = 0
+            best_signal_snr = 0
+        else:
+            best_signal_snr = np.nanmax(corrected_snrs)
+            best_signal_snr_index = np.nanargmax(corrected_snrs)
+            best_signal = transit_results[best_signal_snr_index]
+            max_votes_rate = max(votes_counts) / len(votes)
+            if best_signal_snr > snr_min and max_votes_rate >= self.min_quorum:  # and SDE[a] > SDE_min and FAP[a] < FAP_max):
+                best_signal_score = 1
+            else:
+                best_signal_score = 0
         return CorrectedQuorumBorderSignalSelection(best_signal_score, best_signal_snr,
                                                     basic_signal_selection.curve_index,
                                                     transit_results[basic_signal_selection.curve_index],
